@@ -22,7 +22,7 @@
  */
 
 #if !defined(__WEBKIT_H_INSIDE__) && !defined(BUILDING_WEBKIT)
-#error "Only <webkit2/webkit2.h> can be included directly."
+#error "Only <webkit/webkit.h> can be included directly."
 #endif
 
 #ifndef WebKitWebView_h
@@ -38,7 +38,6 @@
 #include <webkit/WebKitFormSubmissionRequest.h>
 #include <webkit/WebKitHitTestResult.h>
 #include <webkit/WebKitInputMethodContext.h>
-#include <webkit/WebKitJavascriptResult.h>
 #include <webkit/WebKitNavigationAction.h>
 #include <webkit/WebKitNotification.h>
 #include <webkit/WebKitOptionMenu.h>
@@ -56,8 +55,8 @@
 #include <webkit/WebKitWebsitePolicies.h>
 #include <webkit/WebKitWindowProperties.h>
 
+#include <webkit/WebKitNetworkSession.h>
 
-#include <JavaScriptCore/JSBase.h>
 #include <webkit/WebKitColorChooserRequest.h>
 #include <webkit/WebKitWebInspector.h>
 #include <webkit/WebKitWebViewBase.h>
@@ -65,11 +64,6 @@
 G_BEGIN_DECLS
 
 #define WEBKIT_TYPE_WEB_VIEW            (webkit_web_view_get_type())
-#define WEBKIT_WEB_VIEW(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), WEBKIT_TYPE_WEB_VIEW, WebKitWebView))
-#define WEBKIT_IS_WEB_VIEW(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), WEBKIT_TYPE_WEB_VIEW))
-#define WEBKIT_WEB_VIEW_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  WEBKIT_TYPE_WEB_VIEW, WebKitWebViewClass))
-#define WEBKIT_IS_WEB_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  WEBKIT_TYPE_WEB_VIEW))
-#define WEBKIT_WEB_VIEW_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  WEBKIT_TYPE_WEB_VIEW, WebKitWebViewClass))
 
 WEBKIT_DECLARE_DERIVABLE_TYPE (WebKitWebView, webkit_web_view, WEBKIT, WEB_VIEW, WebKitWebViewBase)
 
@@ -154,11 +148,8 @@ typedef enum {
  * detected by trying to display any kind of resource (e.g. an image)
  * from an untrusted source.
  *
- * Enum values previously used to denote the different events which can trigger
- * the detection of insecure content. Since 2.46, WebKit generally no longer
- * loads insecure content in secure contexts.
- *
- * Deprecated: 2.46
+ * Enum values used to denote the different events which can trigger
+ * the detection of insecure content.
  */
 typedef enum {
     WEBKIT_INSECURE_CONTENT_RUN,
@@ -289,7 +280,6 @@ struct _WebKitWebViewClass {
 
     gboolean   (* context_menu)                (WebKitWebView               *web_view,
                                                 WebKitContextMenu           *context_menu,
-                                                GdkEvent                    *event,
                                                 WebKitHitTestResult         *hit_test_result);
 
     void       (* context_menu_dismissed)      (WebKitWebView               *web_view);
@@ -312,7 +302,6 @@ struct _WebKitWebViewClass {
                                                 WebKitColorChooserRequest   *request);
     gboolean   (* show_option_menu)            (WebKitWebView               *web_view,
                                                 WebKitOptionMenu            *menu,
-                                                GdkEvent                    *event,
                                                 GdkRectangle                *rectangle);
 
     void       (* web_process_terminated)      (WebKitWebView               *web_view,
@@ -325,26 +314,45 @@ struct _WebKitWebViewClass {
                                                 WebKitPermissionStateQuery  *query);
 
 
+    /*< private >*/
+    void (*_webkit_reserved0)  (void);
+    void (*_webkit_reserved1)  (void);
+    void (*_webkit_reserved2)  (void);
+    void (*_webkit_reserved3)  (void);
+    void (*_webkit_reserved4)  (void);
+    void (*_webkit_reserved5)  (void);
+    void (*_webkit_reserved6)  (void);
+    void (*_webkit_reserved7)  (void);
+    void (*_webkit_reserved8)  (void);
+    void (*_webkit_reserved9)  (void);
+    void (*_webkit_reserved10) (void);
+    void (*_webkit_reserved11) (void);
+    void (*_webkit_reserved12) (void);
+    void (*_webkit_reserved13) (void);
+    void (*_webkit_reserved14) (void);
+    void (*_webkit_reserved15) (void);
+    void (*_webkit_reserved16) (void);
+    void (*_webkit_reserved17) (void);
+    void (*_webkit_reserved18) (void);
+    void (*_webkit_reserved19) (void);
+    void (*_webkit_reserved20) (void);
+    void (*_webkit_reserved21) (void);
+    void (*_webkit_reserved22) (void);
+    void (*_webkit_reserved23) (void);
+    void (*_webkit_reserved24) (void);
+    void (*_webkit_reserved25) (void);
+    void (*_webkit_reserved26) (void);
+    void (*_webkit_reserved27) (void);
+    void (*_webkit_reserved28) (void);
+    void (*_webkit_reserved29) (void);
+    void (*_webkit_reserved30) (void);
 };
 
 WEBKIT_API GtkWidget *
 webkit_web_view_new                                  (void);
 
-WEBKIT_API GtkWidget *
-webkit_web_view_new_with_related_view                (WebKitWebView             *web_view);
-
-WEBKIT_API GtkWidget *
-webkit_web_view_new_with_context                     (WebKitWebContext          *context);
-
-WEBKIT_API GtkWidget *
-webkit_web_view_new_with_settings                    (WebKitSettings            *settings);
-
-WEBKIT_API GtkWidget *
-webkit_web_view_new_with_user_content_manager        (WebKitUserContentManager  *user_content_manager);
 
 
-WEBKIT_API gboolean
-webkit_web_view_is_ephemeral                         (WebKitWebView             *web_view);
 
 WEBKIT_API gboolean
 webkit_web_view_is_controlled_by_automation          (WebKitWebView             *web_view);
@@ -352,8 +360,8 @@ webkit_web_view_is_controlled_by_automation          (WebKitWebView
 WEBKIT_API WebKitAutomationBrowsingContextPresentation
 webkit_web_view_get_automation_presentation_type     (WebKitWebView             *web_view);
 
-WEBKIT_API WebKitWebsiteDataManager *
-webkit_web_view_get_website_data_manager             (WebKitWebView             *web_view);
+WEBKIT_API WebKitNetworkSession *
+webkit_web_view_get_network_session                  (WebKitWebView             *web_view);
 
 WEBKIT_API WebKitWebContext *
 webkit_web_view_get_context                          (WebKitWebView             *web_view);
@@ -441,7 +449,7 @@ webkit_web_view_go_to_back_forward_list_item         (WebKitWebView
 WEBKIT_API const gchar *
 webkit_web_view_get_uri                              (WebKitWebView             *web_view);
 
-WEBKIT_API cairo_surface_t *
+WEBKIT_API GdkTexture *
 webkit_web_view_get_favicon                          (WebKitWebView             *web_view);
 
 WEBKIT_API const gchar *
@@ -491,8 +499,6 @@ webkit_web_view_execute_editing_command_with_argument(WebKitWebView
 WEBKIT_API WebKitFindController *
 webkit_web_view_get_find_controller                  (WebKitWebView             *web_view);
 
-WEBKIT_DEPRECATED JSGlobalContextRef
-webkit_web_view_get_javascript_global_context        (WebKitWebView             *web_view);
 
 WEBKIT_API void
 webkit_web_view_evaluate_javascript                  (WebKitWebView             *web_view,
@@ -525,49 +531,6 @@ webkit_web_view_call_async_javascript_function_finish(WebKitWebView
                                                       GAsyncResult              *result,
                                                       GError                   **error);
 
-WEBKIT_DEPRECATED_FOR(webkit_web_view_evaluate_javascript) void
-webkit_web_view_run_javascript                       (WebKitWebView             *web_view,
-                                                      const gchar               *script,
-                                                      GCancellable              *cancellable,
-                                                      GAsyncReadyCallback        callback,
-                                                      gpointer                   user_data);
-WEBKIT_DEPRECATED_FOR(webkit_web_view_evaluate_javascript_finish) WebKitJavascriptResult *
-webkit_web_view_run_javascript_finish                (WebKitWebView             *web_view,
-                                                      GAsyncResult              *result,
-                                                      GError                   **error);
-
-WEBKIT_DEPRECATED_FOR(webkit_web_view_evaluate_javascript) void
-webkit_web_view_run_javascript_in_world              (WebKitWebView             *web_view,
-                                                      const gchar               *script,
-                                                      const gchar               *world_name,
-                                                      GCancellable              *cancellable,
-                                                      GAsyncReadyCallback        callback,
-                                                      gpointer                   user_data);
-WEBKIT_DEPRECATED_FOR(webkit_web_view_evaluate_javascript_finish) WebKitJavascriptResult *
-webkit_web_view_run_javascript_in_world_finish       (WebKitWebView             *web_view,
-                                                      GAsyncResult              *result,
-                                                      GError                   **error);
-
-WEBKIT_DEPRECATED_FOR(webkit_web_view_call_async_javascript_function) void
-webkit_web_view_run_async_javascript_function_in_world (WebKitWebView           *web_view,
-                                                        const gchar             *body,
-                                                        GVariant                *arguments,
-                                                        const char              *world_name,
-                                                        GCancellable            *cancellable,
-                                                        GAsyncReadyCallback      callback,
-                                                        gpointer                 user_data);
-
-WEBKIT_DEPRECATED_FOR(webkit_web_view_evaluate_javascript) void
-webkit_web_view_run_javascript_from_gresource        (WebKitWebView             *web_view,
-                                                      const gchar               *resource,
-                                                      GCancellable              *cancellable,
-                                                      GAsyncReadyCallback        callback,
-                                                      gpointer                   user_data);
-
-WEBKIT_DEPRECATED_FOR(webkit_web_view_evaluate_javascript_finish) WebKitJavascriptResult *
-webkit_web_view_run_javascript_from_gresource_finish (WebKitWebView             *web_view,
-                                                      GAsyncResult              *result,
-                                                      GError                   **error);
 
 WEBKIT_API WebKitWebResource *
 webkit_web_view_get_main_resource                    (WebKitWebView             *web_view);
@@ -620,7 +583,7 @@ webkit_web_view_get_snapshot                         (WebKitWebView
                                                       GCancellable              *cancellable,
                                                       GAsyncReadyCallback        callback,
                                                       gpointer                   user_data);
-WEBKIT_API cairo_surface_t *
+WEBKIT_API GdkTexture *
 webkit_web_view_get_snapshot_finish                  (WebKitWebView             *web_view,
                                                       GAsyncResult              *result,
                                                       GError                   **error);
@@ -714,76 +677,6 @@ webkit_web_view_get_web_extension_mode               (WebKitWebView
 WEBKIT_API const gchar*
 webkit_web_view_get_default_content_security_policy  (WebKitWebView             *web_view);
 
-/**
- * webkit_web_view_run_async_javascript_function_in_world: (finish-func webkit_web_view_run_javascript_in_world_finish)
- * @web_view: a #WebKitWebView
- * @body: the JavaScript function body
- * @arguments: a #GVariant with format `{&sv}` storing the function arguments. Function argument values must be one of the following types, or contain only the following GVariant types: number, string, array, and dictionary.
- * @world_name: (nullable): the name of a #WebKitScriptWorld, if no name (i.e. %NULL) is provided, the default world is used. Any value that is not %NULL is a distinct world.
- * @cancellable: (allow-none): a #GCancellable or %NULL to ignore
- * @callback: (scope async): a #GAsyncReadyCallback to call when the script finished
- * @user_data: the data to pass to callback function
- *
- * Asynchronously run @body in the script world with name @world_name of the current page context in
- * @web_view. If WebKitSettings:enable-javascript is FALSE, this method will do nothing. This API
- * differs from webkit_web_view_run_javascript_in_world() in that the JavaScript function can return a
- * Promise and its result will be properly passed to the callback.
- *
- * When the operation is finished, @callback will be called. You can then call
- * webkit_web_view_run_javascript_in_world_finish() to get the result of the operation.
- *
- * For instance here is a dummy example that shows how to pass arguments to a JS function that
- * returns a Promise that resolves with the passed argument:
- *
- * ```c
- * static void
- * web_view_javascript_finished (GObject      *object,
- *                               GAsyncResult *result,
- *                               gpointer      user_data)
- * {
- *     WebKitJavascriptResult *js_result;
- *     JSCValue               *value;
- *     GError                 *error = NULL;
- *
- *     js_result = webkit_web_view_run_javascript_finish (WEBKIT_WEB_VIEW (object), result, &error);
- *     if (!js_result) {
- *         g_warning ("Error running javascript: %s", error->message);
- *         g_error_free (error);
- *         return;
- *     }
- *
- *     value = webkit_javascript_result_get_js_value (js_result);
- *     if (jsc_value_is_number (value)) {
- *         gint32        int_value = jsc_value_to_string (value);
- *         JSCException *exception = jsc_context_get_exception (jsc_value_get_context (value));
- *         if (exception)
- *             g_warning ("Error running javascript: %s", jsc_exception_get_message (exception));
- *         else
- *             g_print ("Script result: %d\n", int_value);
- *         g_free (str_value);
- *     } else {
- *         g_warning ("Error running javascript: unexpected return value");
- *     }
- *     webkit_javascript_result_unref (js_result);
- * }
- *
- * static void
- * web_view_evaluate_promise (WebKitWebView *web_view)
- * {
- *     GVariantDict dict;
- *     g_variant_dict_init (&dict, NULL);
- *     g_variant_dict_insert (&dict, "count", "u", 42);
- *     GVariant *args = g_variant_dict_end (&dict);
- *     const gchar *body = "return new Promise((resolve) => { resolve(count); });";
- *     webkit_web_view_run_async_javascript_function_in_world (web_view, body, arguments, NULL, NULL, web_view_javascript_finished, NULL);
- * }
- * ```
- *
- * Since: 2.38
- *
- * Deprecated: 2.40: Use webkit_web_view_call_async_javascript_function() instead.
- */
-
 G_END_DECLS
 
 #endif
